@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 This module exposes the :class:`OrderedSet` class, which is a collection of
 unique items that maintains the order in which the items were added. An
@@ -30,23 +29,15 @@ entry has an index that can be looked up.
 Based on a recipe originally posted to ActiveState Recipes by Raymond Hettiger,
 and released under the MIT license.
 """
-from __future__ import absolute_import, division, print_function, unicode_literals
 import itertools as it
 from collections import deque
-# import ordered_set
+from collections.abc import MutableSet, Sequence
 
 __all__ = ['OrderedSet', 'oset']
 
 
-try:
-    # Python 3
-    from collections.abc import MutableSet, Sequence
-except ImportError:  # nocover
-    # Python 2.7
-    from collections import MutableSet, Sequence
-
 SLICE_ALL = slice(None)
-__version__ = "3.1"
+__version__ = "3.2"
 
 
 def is_iterable(obj):
